@@ -1,10 +1,9 @@
 import napari
 from pathlib import Path
-
 from magicgui import magicgui
-
 from typing import List
-from pkg_resources import resource_filename
+
+from cellfinder_napari.utils import brainglobe_logo
 
 # TODO:
 # how to store & fetch pre-trained models?
@@ -18,10 +17,6 @@ CUBE_DEPTH = 20
 # If using ROI, how many extra planes to analyse
 MIN_PLANES_ANALYSE = 0
 
-brainglobe_logo = resource_filename(
-    "cellfinder_napari", "resources/brainglobe.png"
-)
-
 
 def detect():
     from math import ceil
@@ -31,6 +26,7 @@ def detect():
     from napari.qt.threading import thread_worker
     from cellfinder_core.main import main as cellfinder_run
     from cellfinder_core.classify.cube_generator import get_cube_depth_min_max
+    from imlib.cells.cells import Cell
     from .utils import cells_to_array
 
     DEFAULT_PARAMETERS = dict(
@@ -119,7 +115,9 @@ def detect():
         Number_of_free_cpus=dict(
             value=DEFAULT_PARAMETERS["Number_of_free_cpus"]
         ),
-        Analyse_local=dict(value=DEFAULT_PARAMETERS["Analyse_local"]),
+        Analyse_local=dict(
+            value=DEFAULT_PARAMETERS["Analyse_local"], label="Analyse local"
+        ),
         Debug=dict(value=DEFAULT_PARAMETERS["Debug"]),
         # Classification_batch_size=dict(max=4096),
         call_button=True,
@@ -159,22 +157,22 @@ def detect():
 
         Parameters
         ----------
+        Signal_image : napari.layers.Image
+             Image layer containing the labelled cells
+        Background_image : napari.layers.Image
+             Image layer withoutlabelled cells
         voxel_size_z : float
             Size of your voxels in the axial dimension
         voxel_size_y : float
-            Size of your voxels in x (left to right)
-        voxel_size_z : float
-            Size of your voxels in the y (top to bottom)
+            Size of your voxels in the y direction (top to bottom)
+        voxel_size_x : float
+            Size of your voxels in the x direction (left to right)
         Soma_diameter : float
             The expected in-plane soma diameter (microns)
         ball_xy_size : float
             Elliptical morphological in-plane filter size (microns)
         ball_z_size : float
             Elliptical morphological axial filter size (microns)
-        Start_plane : int
-            First plane to process (to process a subset of the data)
-        End_plane : int
-            Last plane to process (to process a subset of the data)
         Ball_overlap : float
             Fraction of the morphological filter needed to be filled
             to retain a voxel
@@ -187,9 +185,20 @@ def detect():
         Max_cluster : int
             Largest putative cell cluster (in cubic um) where splitting
             should be attempted
+        Trained_model : Path
+            Trained model file path
+        Start_plane : int
+            First plane to process (to process a subset of the data)
+        End_plane : int
+            Last plane to process (to process a subset of the data)
         Number_of_free_cpus : int
             How many CPU cores to leave free
-        Analyse_local : Only analyse planes around the current position
+        Analyse_local : bool
+            Only analyse planes around the current position
+        Debug : bool
+            Increase logging
+        reset_button :
+            Reset parameters to default
         """
 
         def add_layers(points):
@@ -204,6 +213,7 @@ def detect():
                 symbol="ring",
                 face_color="lightskyblue",
                 visible=False,
+                metadata=dict(point_type=Cell.UNKNOWN),
             )
             viewer.add_points(
                 points,
@@ -213,6 +223,7 @@ def detect():
                 opacity=0.6,
                 symbol="ring",
                 face_color="lightgoldenrodyellow",
+                metadata=dict(point_type=Cell.CELL),
             )
 
         @thread_worker
@@ -303,6 +314,7 @@ def detect():
         '<p><a href="https://docs.brainglobe.info/cellfinder/napari-plugin" style="color:gray;">Documentation</a></p>'
         '<p><a href="https://github.com/brainglobe/cellfinder-napari" style="color:gray;">Source</a></p>'
         '<p><a href="https://www.biorxiv.org/content/10.1101/2020.10.21.348771v2" style="color:gray;">Citation</a></p>'
+        "<p><small>For help, hover the cursor over each parameter.</small>"
     )
     widget.header.native.setOpenExternalLinks(True)
 
